<template>
  <!--系统集成的系统信息页面-->
  <basic-container>
    <avue-crud :option="option"
               :table-loading="loading"
               :data="data"
               :page.sync="page"
               :permission="permissionList"
               ref="crud"
               @search-change="searchChange"
               @cell-dblclick="cellDbClick"
               @search-reset="searchReset"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
      <template slot-scope="scope" slot="menuLeft">
        <vci-docking-search :SearchObject="SearchObject" :page="page" :formInline="formInline" :status="status"></vci-docking-search>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import {getList} from "@/api/docking/data";
import {validatenull} from "@/util/validate";
import {mapGetters} from "vuex";
import website from "@/config/website";

export default {
name: "data",
  data(){
  return {
    //各个类型状态
    status:{
      type:'data',
      sendTypeFlga:false,
      stateTaskDataFlag:false
    },
    //model绑定
    formInline:{
      type:'',
      text:'',
      stateTask:'',
      taskCut:''
    },
    //集成类型死数据
    SearchObject:{
      searchData:[
        {
          label:'数据编码',
          prop: "id",
          value:0
        },
        {
          label:'分类代号',
          prop: "classifyId",
          value:1
        },
        {
          label:'分类名称',
          prop: 'classifyName',
          value:2
        },
        {
          label:'推送类型',
          prop: 'sendType',
          value:3
        },
        {
          label:'是否分解任务',
          prop: 'sendFlag',
          value:4
        },
      ]
    },
    value:'',
    loading: false,
    query: {},
    selectionList: [],
    page: {
      pageSize: 20,
      currentPage: 1,
      total: 0
    },
    data:[],
    option: {
      height:'auto',
      calcHeight: 0,
      tip: false,
      searchShow: false,
      searchMenuSpan: 6,
      border: true,
      index: true,
      viewBtn: true,
      selection: false,
      dialogClickModal: false,
      menu:false,
      column: [
        {
          label: "数据编码",
          prop: "id",
          search: true,
          sortable:true,
          // width:150
        },
        {
          label: "图号",
          prop: "uniqueCode",
          search: true,
          hide:true,
          sortable:true
        },
        {
          label: '分类代号',
          prop: 'classifyId',
          search: true,
          sortable:true,
          // width: 250
        },
        {
          label: '分类名称',
          prop: 'classifyName',
          search: true,
          sortable:true,
        },
        {
          label: '业务类型oid',
          prop: 'btmOid',
          sortable:true,
          hide:true,
          // width: 250
        },
        {
          label: '业务类型id',
          prop: 'btmId',
          sortable:true,
          // width: 150
        },
        {
          label: '推送类型',
          prop: 'sendType',
          search: true,
          sortable:true,
          // width: 150,
          formatter: function (row, column) {
            if (row.sendType === 'Enabled') {
              return '发布';
            } else if (row.sendType === 'TakeBack') {
              return '回收';
            } else if (row.sendType === 'Disabled') {
              return '停用';
            }
          }
        },
        {
          label: '是否分解任务',
          prop: 'sendFlag',
          search: true,
          sortable:true,
          // width: 130,
          html:true,
          align:'center',
          type:'select',
          searchLabelWidth:130,
          dicData: [{key:'true',value:'是'},{key:'false',value:'否'}],
          props: {
            label: "value",
            value: "key"
          },
          formatter : function (row, column) {
            return row.sendFlag == 'true' || row.sendFlag == '1' ? '<i class="el-icon-check" style="color: limegreen;font-size: 20px;font-weight: 800"></i>' : '<i class="el-icon-close" style="color: red;font-size: 20px;font-weight: 800" ></i>'
          }
        }
      ]
    }
  }
  },
  computed:{
    ...mapGetters([ "permission"]),
    permissionList() {
      return {
        addBtn: false,
        viewBtn: false,
        delBtn: false,
        editBtn: false
      };
    }
  },
  methods: {
    async cellDbClick(row, column, cell, event) {
      for (const key in row) {
        if (key === column.property) {
          this.value = row[key];
        }
      }
      try {
        await this.$copyText(this.value);
        this.$message.success('复制成功');
      } catch (error) {
        this.$message.warning('复制失败');
      }
    },
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page);
    },
    onLoad(page, params={}) {
      this.loading = true;
      var query={}
      if (this.query) {
        for (var key in this.query) {
          query['conditionMap["' + key + '"]'] = this.query[key];
        }
      }
      getList(page.currentPage, page.pageSize, Object.assign(params,this.params, query,this.query)).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.selectionClear();
      }).catch(error=>{
        this.$message.error(error);
        this.loading = false;
      });
    }
  }

}
</script>

<style scoped>

</style>
